@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2008-2011 Michael Howitz
+# Copyright (c) 2008-2012 Michael Howitz
 # See also LICENSE.txt
-# $Id: addressbook.py 1427 2011-12-06 07:15:23Z icemac $
+# $Id: addressbook.py 1460 2012-01-06 11:36:19Z icemac $
 
 from icemac.addressbook.i18n import _
 import grokcore.component
@@ -37,7 +37,7 @@ import zope.site.site
 
 class AddressBook(zope.container.btree.BTreeContainer,
                   zope.site.site.SiteManagerContainer):
-    "An address book."
+    """An address book."""
 
     zope.interface.implements(icemac.addressbook.interfaces.IAddressBook)
 
@@ -135,28 +135,24 @@ class AddressBookCreated(object):
 
 @grokcore.component.subscribe(AddressBookCreated)
 def add_more_addressbook_infrastructure(event):
-    "Add more infrastructure which depends on addressbook set as site."
+    """Add infrastructure which depends on address book as site manager."""
     addressbook = event.address_book
     try:
         old_site = zope.component.hooks.getSite()
         zope.component.hooks.setSite(addressbook)
+
         # intid utility
-        if not icemac.addressbook.utils.utility_locally_registered(
-                addressbook, zope.intid.interfaces.IIntIds):
-            intids = zope.app.appsetup.bootstrap.ensureUtility(
-                addressbook, zope.intid.interfaces.IIntIds, '',
-                zope.intid.IntIds)
+        zope.app.appsetup.bootstrap.ensureUtility(
+            addressbook, zope.intid.interfaces.IIntIds, '',
+            zope.intid.IntIds)
 
         # catalog
-        if icemac.addressbook.utils.utility_locally_registered(
-                addressbook, zope.catalog.interfaces.ICatalog):
-            catalog = zope.component.queryUtility(
+        catalog = zope.app.appsetup.bootstrap.ensureUtility(
+            addressbook, zope.catalog.interfaces.ICatalog, '',
+            zope.catalog.catalog.Catalog)
+        if catalog is None:
+            catalog = zope.component.getUtility(
                 zope.catalog.interfaces.ICatalog)
-        else:
-            # add catalog
-            catalog = zope.app.appsetup.bootstrap.ensureUtility(
-                addressbook, zope.catalog.interfaces.ICatalog, '',
-                zope.catalog.catalog.Catalog)
 
         # indexes
         if 'keywords' not in catalog:
@@ -172,17 +168,21 @@ def add_more_addressbook_infrastructure(event):
                     zope.index.text.lexicon.CaseNormalizer()))
 
         # authenticator (PAU)
-        if not icemac.addressbook.utils.utility_locally_registered(
-                addressbook,
-                zope.authentication.interfaces.IAuthentication):
-            pau = zope.app.appsetup.bootstrap.ensureUtility(
-                addressbook, zope.authentication.interfaces.IAuthentication,
-                '',
-                zope.pluggableauth.authentication.PluggableAuthentication)
+        pau = zope.app.appsetup.bootstrap.ensureUtility(
+            addressbook, zope.authentication.interfaces.IAuthentication,
+            '',
+            zope.pluggableauth.authentication.PluggableAuthentication)
+        if pau is not None:
             pau.credentialsPlugins = (u'No Challenge if Authenticated',
                                       u'Flashed Session Credentials',)
             pau.authenticatorPlugins = (u'icemac.addressbook.principals',)
 
+        # principal annotation utility
+        zope.app.appsetup.bootstrap.ensureUtility(
+            addressbook,
+            zope.principalannotation.interfaces.IPrincipalAnnotationUtility,
+            '', zope.principalannotation.utility.PrincipalAnnotationUtility)
+
         # default preferences
         icemac.addressbook.preferences.default.add(addressbook)
     finally:
