@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2011 Michael Howitz
+# Copyright (c) 2008-2012 Michael Howitz
 # See also LICENSE.txt
-# $Id: keyword.py 1229 2011-01-29 17:07:16Z icemac $
+# $Id: keyword.py 1453 2012-01-05 10:36:15Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import gocept.reference.interfaces
@@ -40,10 +40,10 @@ class EditForm(icemac.addressbook.browser.base.GroupEditForm):
 
     def applyChanges(self, data):
         # GroupForm has its own applyChanges but we need the one from
-        # BaseEditForm here as inside the goups no changes are made
-        # but there is a subscriber which raises an error which is
-        # handled by BaseEditForm.
-        return icemac.addressbook.browser.base.BaseEditForm.applyChanges(
+        # _AbstractEditForm here as inside the goups no changes are made but
+        # there is a subscriber which raises an error which is handled by
+        # _AbstractEditForm.
+        return icemac.addressbook.browser.base._AbstractEditForm.applyChanges(
             self, data)
 
     @z3c.form.button.buttonAndHandler(_('Apply'), name='apply')
@@ -52,10 +52,6 @@ class EditForm(icemac.addressbook.browser.base.GroupEditForm):
         # existing action because otherwise we'll loose it.
         super(EditForm, self).handleApply(self, action)
 
-    @z3c.form.button.buttonAndHandler(_('Cancel'), name='cancel')
-    def handleCancel(self, action):
-        self.status = self.noChangesMessage
-
     @z3c.form.button.buttonAndHandler(
         _(u'Delete'), name='delete', condition=can_delete_keyword)
     def handleDelete(self, action):
