@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010-2011 Michael Howitz
+# Copyright (c) 2010-2012 Michael Howitz
 # See also LICENSE.txt
 
 from icemac.addressbook.i18n import _
@@ -9,8 +9,8 @@ import zope.interface
 import zope.schema
 
 
-class IPersonList(zope.interface.Interface):
-    """Person list preferences."""
+class IPersonLists(zope.interface.Interface):
+    """Person lists preferences."""
 
     columns = zope.schema.List(
         title=_('columns'), required=True,
@@ -26,4 +26,8 @@ class IPersonList(zope.interface.Interface):
         title=_('sort direction'),
         source=icemac.addressbook.sources.asc_desc_source)
 
+
+class IPersonListTab(zope.interface.Interface):
+    """Preferences of the person list tab."""
+
     batch_size = zope.schema.Int(title=_('batch size'), min=1)
