@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009-2011 Michael Howitz
+# Copyright (c) 2009-2012 Michael Howitz
 # See also LICENSE.txt
-# $Id: testing.py 1425 2011-12-05 21:08:55Z icemac $
+# $Id: testing.py 1479 2012-03-15 21:00:12Z icemac $
 
 import gocept.selenium.wsgi
 import icemac.addressbook.address
@@ -28,6 +28,7 @@ import z3c.etestbrowser.wsgi
 import zope.annotation.attribute
 import zope.app.publication.httpfactory
 import zope.app.publication.zopepublication
+import zope.app.wsgi
 import zope.app.wsgi.testlayer
 import zope.component
 import zope.component.hooks
@@ -164,9 +165,14 @@ class WSGILayer(plone.testing.Layer):
 
     def testSetUp(self):
         # The layer has to store the database at layer set up (depending
-        # layers require this) but we get a new database at test set up, so
-        # we have to set the right ZODB here:
-        self['wsgi_app'].requestFactory = (
+        # layers require this) but we get a new database demo storage layer
+        # at test set up, so we have to set the new ZODB here:
+        app = self['wsgi_app']
+        while not isinstance(app, zope.app.wsgi.WSGIPublisherApplication):
+            # The outermost WSGI app not necessarily is our Zope app, so we
+            # have to walk down the WSGI-Stack:
+            app = app.app
+        app.requestFactory = (
             zope.app.publication.httpfactory.HTTPPublicationRequestFactory(
                 self['zodbDB']))
 
@@ -191,24 +197,6 @@ class _WSGITestBrowserLayer(zope.testbrowser.wsgi.Layer,
 WSGI_TEST_BROWSER_LAYER = _WSGITestBrowserLayer(name='WSGITestBrowserLayer')
 
 
-class GoceptSeleniumPloneTestingIntegrationLayer(gocept.selenium.wsgi.Layer,
-                                                 plone.testing.Layer):
-    """Layer which integrates gocept.selenium with plone.testing."""
-
-    defaultBases = (WSGI_LAYER, )
-
-    def __init__(self, *args, **kw):
-        # WSGI application is set up in base layers so we cannot access it
-        # here yet:
-        gocept.selenium.wsgi.Layer.__init__(self, application=None)
-        plone.testing.Layer.__init__(self, *args, **kw)
-
-    def setup_wsgi_stack(self, app):
-        return self['wsgi_app']
-
-SELENIUM_LAYER = GoceptSeleniumPloneTestingIntegrationLayer()
-
-
 def setUpAddressBook(self):
     self.old_site = zope.site.hooks.getSite()
     conn, rootObj, rootFolder = createZODBConnection(self['zodbDB'])
@@ -243,14 +231,46 @@ ADDRESS_BOOK_FUNCTIONAL_LAYER = _AddressBookFunctionalLayer(
     name='AddressBookFunctionalLayer')
 
 
+# WSGI layer which creates addressbook at layer set up
+WSGI_ADDRESS_BOOK_LAYER = WSGILayer(
+    bases=[ZODB_ISOLATED_TEST_LAYER,
+           ADDRESS_BOOK_FUNCTIONAL_LAYER],
+    name='WSGIAddressBookFunctionalLayer')
+
 # Layer to use ADDRESS_BOOK_FUNCTIONAL_LAYER with testbrowser:
 WSGI_ADDRESS_BOOK_FUNCTIONAL_LAYER = _WSGITestBrowserLayer(
-    bases=[WSGILayer(bases=[ZODB_ISOLATED_TEST_LAYER,
-                            ADDRESS_BOOK_FUNCTIONAL_LAYER],
-                     name='WSGIAddressBookFunctionalLayer')],
+    bases=[WSGI_ADDRESS_BOOK_LAYER],
     name='TestBrowserAddressBookFunctionalLayer')
 
 
+class GoceptSeleniumPloneTestingIntegrationLayer(gocept.selenium.wsgi.Layer,
+                                                 plone.testing.Layer):
+    """Layer which integrates gocept.selenium with plone.testing."""
+
+    defaultBases = (WSGI_ADDRESS_BOOK_LAYER, )
+
+    def __init__(self, *args, **kw):
+        # WSGI application is set up in base layers so we cannot access it
+        # here yet:
+        gocept.selenium.wsgi.Layer.__init__(self, application=None)
+        plone.testing.Layer.__init__(self, *args, **kw)
+
+    def setup_wsgi_stack(self, app):
+        return self['wsgi_app']
+
+SELENIUM_LAYER = GoceptSeleniumPloneTestingIntegrationLayer()
+
+
+class SeleniumTestCase(gocept.selenium.wsgi.TestCase):
+    """Base test class for selenium tests."""
+    layer = SELENIUM_LAYER
+    level = 2
+
+    def login(self, username='mgr', password='mgrpw'):
+        self.selenium.open("http://%s:%s@%s/" % (
+            username, password, self.selenium.server))
+
+
 def DocFileSuite(*paths, **kw):
     """Project specific DocFileSuite."""
     kw['optionflags'] = (kw.get('optionflags', 0) |
@@ -547,3 +567,15 @@ def create_field(entity_name, type, title, **kw):
     entity = zope.component.getUtility(
         icemac.addressbook.interfaces.IEntity, name=entity_name)
     return entity.addField(field)
+
+
+class InstallationAssertions(object):
+    """Assertions helpful to check automatic installation routines."""
+
+    def assertLocalUtility(self, ab, iface, name=''):
+        self.assertIsNotNone(
+            zope.component.queryUtility(iface, context=ab, name=name))
+
+    def assertAttribute(self, ab, attribute, iface, name=''):
+        self.assertTrue(iface.providedBy(getattr(ab, attribute)))
+        self.assertLocalUtility(ab, iface, name)
